"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _breakpoints = _interopRequireDefault(require("@bootstrap-styled/css-mixins/lib/breakpoints"));

var _lib = _interopRequireDefault(require("map-to-css-modules/lib"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Heading = _interopRequireDefault(require("../../Heading"));

var propTypes = {
  level: _propTypes.default.oneOf([1, 2, 3, 4, 5, 6]).isRequired,
  children: _propTypes.default.node.isRequired,

  /**
   * Replace or remove a className from the component.
   * See example <a href="https://www.npmjs.com/package/map-to-css-modules" target="_blank">here</a>.
   */
  cssModule: _propTypes.default.object,
  // eslint-disable-line react/require-default-props

  /** @ignore */
  className: _propTypes.default.string.isRequired,

  /** Theme variables. Can be: */
  theme: _propTypes.default.shape({
    styleguide: _propTypes.default.shape({
      '$rsg-markdown-heading-color': _propTypes.default.string,
      '$rsg-markdown-heading-line-height': _propTypes.default.string,
      '$rsg-markdown-heading-font-size': _propTypes.default.shape({
        h1: _propTypes.default.string,
        h2: _propTypes.default.string,
        h3: _propTypes.default.string,
        h4: _propTypes.default.string,
        h5: _propTypes.default.string,
        h6: _propTypes.default.string
      }),
      '$rsg-markdown-heading-mobile-line-height': _propTypes.default.string,
      '$rsg-markdown-heading-mobile-font-size': _propTypes.default.shape({
        h1: _propTypes.default.string,
        h2: _propTypes.default.string,
        h3: _propTypes.default.string,
        h4: _propTypes.default.string,
        h5: _propTypes.default.string,
        h6: _propTypes.default.string
      }),
      '$rsg-markdown-heading-font-weight': _propTypes.default.shape({
        h1: _propTypes.default.string,
        h2: _propTypes.default.string,
        h3: _propTypes.default.string,
        h4: _propTypes.default.string,
        h5: _propTypes.default.string,
        h6: _propTypes.default.string
      })
    })
  })
};
var defaultProps = {
  cssModule: null,
  theme: {
    styleguide: {
      '$rsg-markdown-heading-line-height': '1',
      '$rsg-markdown-heading-font-size': {
        h1: '30px',
        h2: '28px',
        h3: '26px',
        h4: '24px',
        h5: '22px',
        h6: '20px'
      },
      '$rsg-markdown-heading-margin': '0',
      '$rsg-markdown-heading-color': '#383b3d',
      '$rsg-markdown-heading-padding': '20px 0 15px 0',
      '$rsg-markdown-heading-mobile-line-height': '1',
      '$rsg-markdown-heading-mobile-font-size': {
        h1: '28px',
        h2: '26px',
        h3: '24px',
        h4: '22px',
        h5: '20px',
        h6: '18px'
      },
      '$rsg-markdown-heading-font-weight': {
        h1: '300',
        h2: '300',
        h3: '300',
        h4: '300',
        h5: '300',
        h6: '300'
      }
    }
  }
};

function MarkdownHeadingRenderer(_ref) {
  var level = _ref.level,
      className = _ref.className,
      children = _ref.children,
      cssModule = _ref.cssModule;
  return _react.default.createElement(_Heading.default, {
    level: level,
    className: (0, _lib.default)((0, _classnames.default)(className, 'rsg-markdown-heading'), cssModule)
  }, children);
}

MarkdownHeadingRenderer.propTypes = propTypes;
MarkdownHeadingRenderer.defaultProps = defaultProps;
var StyledMarkdownHeadingRenderer = (0, _styledComponents.default)(MarkdownHeadingRenderer).withConfig({
  displayName: "MarkdownHeadingRenderer__StyledMarkdownHeadingRenderer",
  componentId: "s94yhw-0"
})(["", ""], function (props) {
  return "\n  &.rsg-markdown-heading {\n    &.rsg-markdown-heading {\n      color: ".concat(props.theme.styleguide['$rsg-markdown-heading-color'], ";\n    }\n    ").concat(_breakpoints.default.up('xs', props.theme['$grid-breakpoints'], "\n      &.rsg-markdown-heading {\n        line-height: ".concat(props.theme.styleguide['$rsg-markdown-heading-mobile-line-height'], ";\n      }\n      &.rsg-markdown-heading.h1 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-mobile-font-size'].h1, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h1, ";\n      }\n      &.rsg-markdown-heading.h2 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-mobile-font-size'].h2, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h2, ";\n      }\n      &.rsg-markdown-heading.h3 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-mobile-font-size'].h3, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h3, ";\n      }\n      &.rsg-markdown-heading.h4 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-mobile-font-size'].h4, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h4, ";\n      }\n      &.rsg-markdown-heading.h5 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-mobile-font-size'].h5, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h5, ";\n      }\n      &.rsg-markdown-heading.h6 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-mobile-font-size'].h6, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h6, ";\n        font-style: 'italic';\n      }\n    ")), "\n \n  ").concat(_breakpoints.default.up('md', props.theme['$grid-breakpoints'], "\n      &.rsg-markdown-heading {\n        line-height: ".concat(props.theme.styleguide['$rsg-markdown-heading-line-height'], ";\n      }\n      &.rsg-markdown-heading.h1 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-size'].h1, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h1, ";\n      }\n      &.rsg-markdown-heading.h2 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-size'].h2, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h2, ";\n      }\n      &.rsg-markdown-heading.h3 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-size'].h3, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h3, ";\n      }\n      &.rsg-markdown-heading.h4 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-size'].h4, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h4, ";\n      }\n      &.rsg-markdown-heading.h5 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-size'].h5, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h5, ";\n      }\n      &.rsg-markdown-heading.h6 {\n        font-size: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-size'].h6, ";\n        font-weight: ").concat(props.theme.styleguide['$rsg-markdown-heading-font-weight'].h6, ";\n        font-style: 'italic';\n      }\n    ")), "}\n ");
});
StyledMarkdownHeadingRenderer.propTypes = propTypes;
StyledMarkdownHeadingRenderer.defaultProps = defaultProps;
var _default = StyledMarkdownHeadingRenderer;
exports.default = _default;
module.exports = exports.default;